VelrSavepoint

Struct VelrSavepoint 

pub struct VelrSavepoint<'tx> { /* private fields */ }
A scoped savepoint handle within a transaction (thread-affine).

This is the RAII/scoped savepoint API:

Drop behavior

If dropped without explicit release/rollback, the runtime rolls back to the savepoint and releases it.

Implementations

Source

impl VelrSavepoint<'_>

pub fn release(self) -> Result<()>

Release this savepoint.

Consumes the savepoint handle. After this call, the savepoint is finalized and cannot be used again.

Note: the underlying C ABI consumes the savepoint handle even if an error is returned.

pub fn rollback(self) -> Result<()>

Roll back to this savepoint and release it.

Consumes the savepoint handle. After this call, the savepoint is finalized and cannot be used again.

Note: the underlying C ABI consumes the savepoint handle even if an error is returned.